#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 postgrest
version:              10.1.0
visibility:           public
id:                   postgrest-10.1.0-8iD9uDfQsNo7kSlTPiRUEP
key:                  postgrest-10.1.0-8iD9uDfQsNo7kSlTPiRUEP
license:              MIT
maintainer:           Steve Chavez <stevechavezast@gmail.com>
author:               Joe Nelson, Adam Baker, Steve Chavez
homepage:             https://postgrest.org
synopsis:             REST API for any Postgres database
description:
    Reads the schema of a PostgreSQL database and creates RESTful routes
    for tables, views, and functions, supporting all HTTP methods that security
    permits.

category:             Executable, PostgreSQL, Network APIs
abi:                  059518f0a09baba85bbbaafe1c13cc90
exposed:              True
exposed-modules:
    PostgREST.ApiRequest PostgREST.ApiRequest.Preferences
    PostgREST.ApiRequest.QueryParams PostgREST.ApiRequest.Types
    PostgREST.App PostgREST.AppState PostgREST.Auth PostgREST.CLI
    PostgREST.Config PostgREST.Config.Database PostgREST.Config.JSPath
    PostgREST.Config.PgVersion PostgREST.Config.Proxy PostgREST.Cors
    PostgREST.Error PostgREST.Logger PostgREST.MediaType PostgREST.Plan
    PostgREST.Plan.CallPlan PostgREST.Plan.MutatePlan
    PostgREST.Plan.ReadPlan PostgREST.Query
    PostgREST.Query.QueryBuilder PostgREST.Query.SqlFragment
    PostgREST.Query.Statements PostgREST.RangeQuery PostgREST.Response
    PostgREST.Response.GucHeader PostgREST.Response.OpenAPI
    PostgREST.SchemaCache PostgREST.SchemaCache.Identifiers
    PostgREST.SchemaCache.Proc PostgREST.SchemaCache.Relationship
    PostgREST.SchemaCache.Table PostgREST.Unix PostgREST.Version
    PostgREST.Workers

hidden-modules:       Paths_postgrest
import-dirs:          /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/postgrest
hs-libraries:         HSpostgrest-10.1.0-8iD9uDfQsNo7kSlTPiRUEP
depends:
    HTTP-4000.5.0-9Hqr0tIiC7ZGzv1qBrb2W4
    Ranged-sets-0.5.0-A0qLeXpShcYKMwbEmWo7DV
    aeson-2.2.2.0-mVpxNJADFA3tVhrw9PzvG
    auto-update-0.1.6-66fieeWpd84HrPD2b2utJ4 base-4.18.2.1
    base64-bytestring-1.2.1.0-3MnxOO7xl0P127Exi8mxw2
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-42CJmR7jfDI1QxR1AA3Hru
    cassava-0.5.4.1-2Rx1DDFwJ2w4rIh2koLxEx
    configurator-pg-0.2.11-EabUA1O20bWA0CS3GZKZ6 containers-0.6.7
    contravariant-extras-0.3.5.4-Jp1EzHgD0E5KQ707vKnuxI
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5 directory-1.3.8.5
    either-5.0.3-JkOYlMFA21vDSVcoYpBsXz
    gitrev-1.3.1-HjgHeGOzFY1JvYhlt8eDSs
    hasql-1.6.1.1-3ZLIU1DaautDuE9yb1n9Kt
    hasql-dynamic-statements-0.3.1.2-7Faj59h9Fk4JMk1FCK7UGc
    hasql-notifications-0.2.0.6-AlOKc0xOPCJ1IFKc1gmLkZ
    hasql-pool-0.8.0.3-3tKNmFRGEkIASoMUwEBtMl
    hasql-transaction-1.0.1.3-4GNj2C7vesJ42TTxkH0Q3n
    heredoc-0.2.0.0-6fzsisYvDUd6tBbd4jIzIt
    http-types-0.12.4-1B8W97d7Bm7JkBvipzT6Xa
    insert-ordered-containers-0.2.5.3-1i32KUQbWNS49oa9XiXv54
    interpolatedstring-perl6-1.0.2-1vBh2oPepPKB0bAdGhtVgA
    jose-0.11-GooLD85GZSpE4Hp9fTvUY7 lens-5.3.5-KA5gcUGZYMJ4Yj2DW4uyDf
    lens-aeson-1.2.3-9vzGEq3SnHm1ppljJ0sdqo mtl-2.3.1
    network-3.1.4.0-Ds5DY5mKlnsDQk8HC4tJQL
    network-uri-2.6.4.2-6IsL4l5xPlJ2SbjqeOZPL6
    optparse-applicative-0.18.1.0-47hFtTaenhPJTeGKwQSLW6
    parsec-3.1.16.1 protolude-0.3.5-8zpgymbcdhxLFs8yER14Fo
    regex-tdfa-1.3.2.5-7A9AvRIGkk4HgHOwz4zjio
    retry-0.9.3.1-LQJiE4gTHP2GyztIPNPndh
    scientific-0.3.8.1-Chb8huA5Cwn7PjEJBSEbMQ
    swagger2-2.9-IvxS0ACf4Rm2KGlQt852gU text-2.0.2 time-1.12.2
    unix-2.8.4.0 unordered-containers-0.2.21-8KUdGsL7zFhFWAw4aaEQtP
    vault-0.3.1.6-Izfbd4ZXUHn5Egg8eCijcw
    vector-0.13.2.0-KNP2q6eDEp8AmnRr9wgHHB
    wai-3.2.4-Ek9dLJReg1i3Yf2RaaBEiZ
    wai-cors-0.2.7-14tnkiRGoUv9jwAjN38YZH
    wai-extra-3.1.18-Zje9RgRHuy7Q1wISX9Cn2
    wai-logger-2.5.0-83HIKJUgw58DTokg4sPP5P
    warp-3.4.0-Czkfmqsya4xIjRj8cC9rD4

haddock-interfaces:   /usr/share/doc/postgrest/html/postgrest.haddock
haddock-html:         /usr/share/doc/postgrest/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

